#!/bin/sh
# If SCHRODINGER is not available, then list the available installations in 
# its parent directory
echo ""
echo "################ Checking SCHRODINGER #################"
echo ""
if [ ! -d $SCHRODINGER ]
then
    echo "SCHRODINGER installation is not available at" $SCHRODINGER
    par_dir=`dirname $SCHRODINGER`
    echo "Available SCHRODINGER installations at" $par_dir
    echo "======================================================="
    for dir in `ls $par_dir`
    do  
        if [ -d $par_dir/$dir"/knime-v"* ]
        then
            echo $dir
        fi
    done
else
    cat $SCHRODINGER/version.txt
fi


# If PYMOL_EXEC is not available, then post a clear error message
if [ ! -f $PYMOL_EXEC ]
then
    echo ""
    echo "################### Checking PYMOL ####################"
    echo ""
    echo "Invalid PYMOL_EXEC path:" $PYMOL_EXEC
    pymol_dir=`dirname $PYMOL_EXEC`
    par_dir=`dirname $pymol_dir`
    echo "Available PyMOL installations at" $par_dir
    echo "======================================================="
    for dir in `ls $par_dir`
    do  
        if [ -f $par_dir/$dir/"pymol" ]
        then
            echo $dir
        fi
    done
fi

if [ -d $SCHRODINGER ]
then
    # Check KNIME_MAIN license feature
    echo ""
    echo "################## Checking licenses ##################"
    echo ""
    echo "Checking MMLIBS license:"
    $SCHRODINGER/utilities/lictest -t MMLIBS -v
    echo "Checking KNIME_MAIN license:"
    $SCHRODINGER/utilities/lictest -t KNIME_MAIN -v

    echo ""
    echo "################## Checking Jobserver #################"
    echo ""
    echo "Local server status:"
    $SCHRODINGER/jsc local-server-status

    echo ""
    $SCHRODINGER/jsc cert list > cert_list.txt

    # Assuming the output of `jsc cert list` is:
    # User certificates exist for the following server addresses:
    #  localhost:40045
    #  apollo:8030
    #  boltsub3.schrodinger.com:8030

    first_line=1
    cat cert_list.txt | while read line
    do
        if [ $first_line = 1 ]
        then
            echo $line
            first_line=0
        else
            echo ""
            $SCHRODINGER/jsc server-info $line
        fi
    done

fi
